[java-identity-provider COMMIT] in /trunk: idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequest...

noreply at shibboleth.net noreply at shibboleth.net
Sun Apr 1 19:54:49 BST 2012


Author: lajoie
Date: Sun Apr  1 19:54:49 2012
New Revision: 4155

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4155&view=rev
Log:
more authn work

Added:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/UserAgentAddressContext.java   (with props)
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUserAgentAddress.java   (with props)
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/FinalizeAuthentication.java   (contents, props changed)
      - copied, changed from r4154, trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/CheckCompletedAuthenticationState.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ValidateUserAgentAddress.java   (with props)
Removed:
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/CheckCompletedAuthenticationState.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ValidateClientIpAddress.java
Modified:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/KerberosTicketContext.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/UsernamePasswordContext.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/X509CertificateContext.java
    trunk/idp-authn-impl/pom.xml
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromBasicAuthorizationHeader.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromFormResponse.java
    trunk/idp-authn-impl/src/main/java/net/shibboleth/idp/authn/impl/ExtractUsernamePasswordFromWssToken.java

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java?rev=4155&r1=4154&r2=4155&view=diff
==============================================================================
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java Sun Apr  1 19:54:49 2012
@@ -94,9 +94,14 @@
         return completionInstant;
     }
 
-    /** Sets the completion time of the authentication attempt to the current time. */
-    public void setCompletionInstant() {
+    /**
+     * Sets the completion time of the authentication attempt to the current time.
+     * 
+     * @return this authentication request context
+     */
+    public AuthenticationRequestContext setCompletionInstant() {
         completionInstant = System.currentTimeMillis();
+        return this;
     }
 
     /**
@@ -112,9 +117,12 @@
      * Sets whether authentication must occur even if an existing authentication event exists and is still valid.
      * 
      * @param force whether authentication must occur even if an existing authentication event exists and is still valid
-     */
-    public void setForcingAuthentication(boolean force) {
+     * 
+     * @return this authentication request context
+     */
+    public AuthenticationRequestContext setForcingAuthentication(boolean force) {
         forcingAuthentication = force;
+        return this;
     }
 
     /**
@@ -136,9 +144,12 @@
      * 
      * @param workflow authentication workflow to use if user authentication is needed but no particular workflows are
      *            requested
-     */
-    public void setDefaultWorfklow(@Nullable final AuthenticationWorkflowDescriptor workflow) {
+     * 
+     * @return this authentication request context
+     */
+    public AuthenticationRequestContext setDefaultWorfklow(@Nullable final AuthenticationWorkflowDescriptor workflow) {
         defaultWorfklow = Optional.fromNullable(workflow);
+        return this;
     }
 
     /**
@@ -156,13 +167,15 @@
      * Sets the authentication workflows, in order of preference, that must be used if user authentication is required.
      * 
      * @param workflows authentication workflows, in order of preference, that must be used if user authentication is
-     *            required, may be null or contain null elements
-     */
-    public void
-            setRequestedWorkflows(@Nullable @NullableElements final List<AuthenticationWorkflowDescriptor> workflows) {
+     *            required
+     * 
+     * @return this authentication request context
+     */
+    public AuthenticationRequestContext setRequestedWorkflows(
+            @Nullable @NullableElements final List<AuthenticationWorkflowDescriptor> workflows) {
         if (workflows == null || workflows.isEmpty()) {
             requestedWorkflows = Collections.emptyList();
-            return;
+            return this;
         }
 
         ArrayList<AuthenticationWorkflowDescriptor> descriptors = new ArrayList<AuthenticationWorkflowDescriptor>();
@@ -183,6 +196,8 @@
         } else {

[... 325 lines stripped ...]


More information about the commits mailing list